@@ -1,12 +1,12 @@
 # run tests on Travis (these tests depend on Chrome)
 
-print_pdf = function(input, output = tempfile(), async = FALSE) {
+print_pdf = function(input, output = tempfile(), ...) {
   chrome_print(
     input, output,
     # use --no-sandbox with travis
     # https://docs.travis-ci.com/user/chrome#sandboxing
     extra_args = c('--disable-gpu', '--no-sandbox'),
-    async = async
+    ...
   )
 }
 
